package
Version:
v0.7.0
Opens a new window with list of versions in this module.
Published: Apr 12, 2020
License: GPL-3.0
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ConfWebAPI struct {
Enable bool `toml:"enable"`
Hostname string `toml:"hostname" valid:"hostname"`
Port int `toml:"port" valid:"port"`
Environment string `toml:"environment"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.